@@ -8,6 +8,7 @@ TOLERANCE = 2e-2
 centroids = {
     'jacksonville-untextured.zip': {'x': -81.6634, 'y': 30.3234},
     'jacksonville-textured.zip': {'x': -81.6634, 'y': 30.3234},
+    'jacksonville-point-cloud-3d-tiles.zip': {'x': -81.6634, 'y': 30.3234},
     'dragon.zip': {'x': -75.6079, 'y': 40.0439},
 }
 
@@ -17,11 +18,12 @@ centroids = {
     [
         'jacksonville-untextured.zip',
         'jacksonville-textured.zip',
+        'jacksonville-point-cloud-3d-tiles.zip',
         'dragon.zip',
     ],
 )
 @pytest.mark.django_db(transaction=True)
-def test_mesh_3d_etl(sample_file):
+def test_tiles_3d_etl(sample_file):
     paths = datastore.fetch(sample_file, processor=Unzip())
 
     entry = create_tiles3d_from_paths(paths)
